@@ -12,7 +12,6 @@ from pprint import pformat
 from tornado.options import options
 from tornado.options import parse_command_line, parse_config_file
 from tornado.log import enable_pretty_logging
-from tornado.auth import GoogleOAuth2Mixin
 from celery.bin.base import Command
 
 from . import __version__
@@ -32,7 +31,7 @@ class FlowerCommand(Command):
         env_options = filter(lambda x: x.startswith(self.ENV_VAR_PREFIX),
                              os.environ)
         for env_var_name in env_options:
-            name = env_var_name.lstrip(self.ENV_VAR_PREFIX).lower()
+            name = env_var_name.replace(self.ENV_VAR_PREFIX, '', 1).lower()
             value = os.environ[env_var_name]
             option = options._options[name]
             if option.multiple:
@@ -41,7 +40,7 @@ class FlowerCommand(Command):
                 value = option.type(value)
             setattr(options, name, value)
 
-        argv = list(filter(self.flower_option, argv))
+        argv = list(filter(self.is_flower_option, argv))
         # parse the command line to get --conf option
         parse_command_line([prog_name] + argv)
         try:
@@ -63,10 +62,10 @@ class FlowerCommand(Command):
             enable_pretty_logging()
 
         if options.auth:
-            settings[GoogleOAuth2Mixin._OAUTH_SETTINGS_KEY] = {
-                'key': options.oauth2_key or os.environ.get('FLOWER_GOOGLE_OAUTH2_KEY'),
-                'secret': options.oauth2_secret or os.environ.get('FLOWER_GOOGLE_OAUTH2_SECRET'),
-                'redirect_uri': options.oauth2_redirect_uri or os.environ.get('FLOWER_GOOGLE_OAUTH2_REDIRECT_URI'),
+            settings['oauth'] = {
+                'key': options.oauth2_key or os.environ.get('FLOWER_OAUTH2_KEY'),
+                'secret': options.oauth2_secret or os.environ.get('FLOWER_OAUTH2_SECRET'),
+                'redirect_uri': options.oauth2_redirect_uri or os.environ.get('FLOWER_AUTH2_REDIRECT_URI'),
             }
 
         if options.certfile and options.keyfile:
@@ -103,7 +102,7 @@ class FlowerCommand(Command):
             super(FlowerCommand, self).early_version(argv)
 
     @staticmethod
-    def flower_option(arg):
+    def is_flower_option(arg):
         name, _, value = arg.lstrip('-').partition("=")
         name = name.replace('-', '_')
         return hasattr(options, name)
