@@ -47,7 +47,9 @@ handlers = [
     # Task API
     (r"/api/tasks", tasks.ListTasks),
     (r"/api/task/types", tasks.ListTaskTypes),
+    (r"/api/queues/length", tasks.GetQueueLengths),
     (r"/api/task/info/(.*)", tasks.TaskInfo),
+    (r"/api/task/apply/(.+)", tasks.TaskApply),
     (r"/api/task/async-apply/(.+)", tasks.TaskAsyncApply),
     (r"/api/task/send-task/(.+)", tasks.TaskSend),
     (r"/api/task/result/(.+)", tasks.TaskResult),
