@@ -45,7 +45,7 @@ class BrokerBase(object):
 
 
 class RabbitMQ(BrokerBase):
-    def __init__(self, broker_url, http_api, io_loop=None):
+    def __init__(self, broker_url, http_api, io_loop=None, **kwargs):
         super(RabbitMQ, self).__init__(broker_url)
         self.io_loop = io_loop or ioloop.IOLoop.instance()
 
@@ -59,12 +59,13 @@ class RabbitMQ(BrokerBase):
             http_api = "http://{0}:{1}@{2}:15672/api/{3}".format(
                 self.username, self.password, self.host, self.vhost)
 
-        self._http_api = http_api
+        self.validate_http_api(http_api)
+        self.http_api = http_api
 
     @gen.coroutine
     def queues(self, names):
-        url = urljoin(self._http_api, 'queues/' + self.vhost)
-        api_url = urlparse(self._http_api)
+        url = urljoin(self.http_api, 'queues/' + self.vhost)
+        api_url = urlparse(self.http_api)
         username = unquote(api_url.username or '') or self.username
         password = unquote(api_url.password or '') or self.password
 
@@ -86,8 +87,21 @@ class RabbitMQ(BrokerBase):
         else:
             response.rethrow()
 
+    @classmethod
+    def validate_http_api(cls, http_api):
+        url = urlparse(http_api)
+        if url.scheme not in ('http', 'https'):
+            raise ValueError("Invalid http api schema: %s" % url.scheme)
+        if not url.path.startswith('/api/'):
+            raise ValueError("Invalid http api path: %s" % url.path)
+
+
+DEFAULT_REDIS_PRIORITY_STEPS = [0, 3, 6, 9]
+
 
 class Redis(BrokerBase):
+    sep = '\x06\x16'
+
     def __init__(self, broker_url, *args, **kwargs):
         super(Redis, self).__init__(broker_url)
         self.host = self.host or 'localhost'
@@ -97,12 +111,31 @@ class Redis(BrokerBase):
         if not redis:
             raise ImportError('redis library is required')
 
-        self._redis = redis.Redis(host=self.host, port=self.port,
-                                  db=self.vhost, password=self.password)
+        self.redis = redis.Redis(host=self.host, port=self.port,
+                                 db=self.vhost, password=self.password)
+
+        broker_options = kwargs.get('broker_options')
+
+        if broker_options and 'priority_steps' in broker_options:
+            self.priority_steps = broker_options['priority_steps']
+        else:
+            self.priority_steps = DEFAULT_REDIS_PRIORITY_STEPS
+
+    def _q_for_pri(self, queue, pri):
+        if pri not in self.priority_steps:
+            raise ValueError('Priority not in priority steps')
+        return '{0}{1}{2}'.format(*((queue, self.sep, pri) if pri else (queue, '', '')))
 
     @gen.coroutine
     def queues(self, names):
-        raise gen.Return([dict(name=x, messages=self._redis.llen(x)) for x in names])
+        queue_stats = []
+        for name in names:
+            priority_names = [self._q_for_pri(name, pri) for pri in self.priority_steps]
+            queue_stats.append({
+                'name': name,
+                'messages': sum([self.redis.llen(x) for x in priority_names])
+            })
+        raise gen.Return(queue_stats)
 
     def _prepare_virtual_host(self, vhost):
         if not isinstance(vhost, numbers.Integral):
