@@ -18,14 +18,20 @@ class BrokerView(BaseHandler):
     @gen.coroutine
     def get(self):
         app = self.application
+        broker_options = self.capp.conf.BROKER_TRANSPORT_OPTIONS
 
         http_api = None
         if app.transport == 'amqp' and app.options.broker_api:
             http_api = app.options.broker_api
 
         broker = Broker(app.capp.connection().as_uri(include_password=True),
-                        http_api=http_api)
+                        http_api=http_api, broker_options=broker_options)
+
         queue_names = ControlHandler.get_active_queue_names()
+
+        if not queue_names:
+            queue_names = set([self.capp.conf.CELERY_DEFAULT_QUEUE])
+
         queues = yield broker.queues(sorted(queue_names))
 
         self.render("broker.html",
