@@ -4,24 +4,26 @@ except ImportError:
     from urllib import urlencode
 
 import tornado.testing
+import tornado.options
 
 import celery
 
 from flower.app import Flower
 from flower.urls import handlers
 from flower.events import Events
-from flower.state import State
-from flower.settings import APP_SETTINGS
+from flower.urls import settings
+from flower import command  # side effect - define options
 
 
 class AsyncHTTPTestCase(tornado.testing.AsyncHTTPTestCase):
-    def get_app(self, celery_app=None, events=None, state=None):
-        celery_app = celery_app or celery.Celery()
-        events = events or Events(celery_app)
-        state = state or State(celery_app)
-        self.app = Flower(celery_app=celery_app, events=events,
-                          state=state, handlers=handlers, **APP_SETTINGS)
-        return self.app
+    def get_app(self):
+        capp = celery.Celery()
+        events = Events(capp)
+        app = Flower(capp=capp, events=events,
+                     options=tornado.options.options,
+                     handlers=handlers, **settings)
+        app.delay = lambda method, *args, **kwargs: method(*args, **kwargs)
+        return app
 
     def get(self, url, **kwargs):
         return self.fetch(url, **kwargs)
