@@ -3,21 +3,25 @@ from tests import AsyncHTTPTestCase
 
 
 class AuthTests(AsyncHTTPTestCase):
-    def get_app(self, celery_app=None, events=None, state=None):
-        super(AuthTests, self).get_app(celery_app, events, state)
-        self.app.basic_auth = "hello:world"
-        return self.app
-
     def test_auth_without_credentials(self):
+        ba = self._app.options.basic_auth
+        self._app.options.basic_auth = ["hello:world"]
         r = self.get('/')
+        self._app.options.basic_auth = ba
         self.assertEqual(401, r.code)
 
     def test_auth_with_bad_credentials(self):
+        ba = self._app.options.basic_auth
+        self._app.options.basic_auth = ["hello:world"]
         credentials = base64.b64encode("not:good".encode()).decode()
         r = self.get('/', headers={"Authorization": "Basic " + credentials})
+        self._app.options.basic_auth = ba
         self.assertEqual(401, r.code)
 
     def test_auth_with_good_credentials(self):
+        ba = self._app.options.basic_auth
+        self._app.options.basic_auth = ["hello:world"]
         credentials = base64.b64encode("hello:world".encode()).decode()
         r = self.get('/', headers={"Authorization": "Basic " + credentials})
+        self._app.options.basic_auth = ba
         self.assertEqual(200, r.code)
